========================
``phydms``
========================
.. image:: https://travis-ci.org/jbloomlab/phydms.svg?branch=master
    :target: https://travis-ci.org/jbloomlab/phydms

``phydms`` enables **phy**\logenetic analyses using **d**\eep **m**\utational **s**\canning data to inform the substitution models. It implements **Exp**\erimentally informed **c**\odon **m**\odels (*ExpCM*) for phylogenetic inference and the detection of biologically interesting selection.

``phydms`` is written by the `Bloom lab`_ (see https://github.com/jbloomlab/phydms/contributors for a full list of contributors).

See the `phydms documentation`_ for information about using ``phydms`` and details about the recommended installation process.

The `phydms source code`_ is freely available under a `GPLv3`_ license.

If you use ``phydms``, please `cite it appropriately`_.


.. _`Jesse Bloom`: http://research.fhcrc.org/bloom/en.html
.. _`phydms documentation`: http://jbloomlab.github.io/phydms/
.. _`phydms source code`: https://github.com/jbloomlab/phydms
.. _`GPLv3`: http://www.gnu.org/copyleft/gpl.html
.. _`Bloom lab`: http://labs.fhcrc.org/bloom
.. _`cite it appropriately`: http://jbloomlab.github.io/phydms/acknowledgments.html
